pub struct SourceEncodingDescriptorParts {
pub encoding_id: SourceEncodingId,
pub source_id: PublishedSourceId,
pub rid: Option<Rid>,
pub primary_ssrc: Option<Ssrc>,
pub repair_ssrc: Option<Ssrc>,
pub max_bitrate: Option<Bitrate>,
pub resolution_scale: Option<u16>,
pub max_framerate: Option<u16>,
pub policy_role: Option<UploadLayerPolicyRole>,
pub negotiated_format: Option<MediaFormat>,
}Expand description
Construction input for SourceEncodingDescriptor
The fields are optional where negotiation may not have learned the fact yet. The source and encoding ids must still be stable before the descriptor is stored in room state
Fields
encoding_id: SourceEncodingIdStable encoding id allocated by the room-domain registry.
source_id: PublishedSourceIdParent source id.
rid: Option<Rid>Negotiated RID for RID-based simulcast.
primary_ssrc: Option<Ssrc>Primary RTP SSRC when available.
repair_ssrc: Option<Ssrc>Repair RTP SSRC when available.
max_bitrate: Option<Bitrate>Optional bitrate ceiling advertised for this encoding.
resolution_scale: Option<u16>Optional resolution downscale advertised for this encoding.
max_framerate: Option<u16>Optional frame-rate ceiling advertised for this encoding.
policy_role: Option<UploadLayerPolicyRole>Optional policy role advertised for this encoding.
negotiated_format: Option<MediaFormat>Negotiated codec and payload information when available.